<?php

class Document {

	var $ID;
	var $details;


	function __construct($ID) {
		if (is_numeric($ID)) {
			$this->ID = $ID;
			$this->details = get_post($this->ID);
		} else {
			if (is_array($ID)) {
				$ID = (object) $ID;
			}
			$this->details = $ID;
			$this->ID = $this->details->ID;
		}
	}

	function __get($field) {
		switch ($field) {
			case 'link':
				return wp_get_attachment_url($this->ID);
			case 'path':
				return str_replace(get_site_url().'/',ABSPATH,$this->link);
			case 'icon':
				return '<i class="fa fa-file" aria-hidden="true"></i>';
			case 'data':
				return wp_get_attachment_metadata($this->ID);
			case 'type':
				$mime = explode('/',$this->post_mime_type);
				return count($mime) > 1? strtoupper($mime[1]) : '';
			case 'size':
				return fileSizeString(filesize( get_attached_file( $this->ID ) ));			
			default:
				if (is_object($this->details) && property_exists($this->details,$field)) {
					return $this->details->$field;
				}
		}

	}
	
	static function getByUUID($uuid) {
		return Image::getByUUID($uuid);
	}		
	
	function image($width=0,$height=0) {
		if ($this->post_mime_type == 'application/pdf') {
			$path = str_replace(get_site_url().'/', ABSPATH, $this->link);
			$pathinfo = pathinfo($path);
			
			$outfile = $pathinfo['filename'].'.'.$width.'.'.$height.'.jpg';
			if (!file_exists(ABSPATH.'/wp-content/uploads/cache/'.$outfile)) {
				$im = new imagick($path.'[0]');
				$im->setBackgroundColor(new ImagickPixel('white')); 
				$im->setColorSpace(imagick::COLORSPACE_RGB);
				$im->setImageFormat('jpeg');
				$im->resizeImage ($width, $height, Imagick::FILTER_GAUSSIAN, 1);
				$im->writeimage(ABSPATH.'/wp-content/uploads/cache/'.$outfile);
			}
			
			return get_site_url().'/wp-content/uploads/cache/'.$outfile;
		} else {
			return $this->icon;
		}
	}
	
	function src($width=0,$height=0) {
		if ($this->post_mime_type == 'application/pdf') {
			$path = str_replace(get_site_url().'/', ABSPATH, $this->link);
			$pathinfo = pathinfo($path);
			
			$outfile = $pathinfo['filename'].'.'.$width.'.'.$height.'.jpg';
			if (!file_exists(ABSPATH.'/wp-content/uploads/cache/'.$outfile)) {
				$im = new imagick($path.'[0]');
				$im->setBackgroundColor(new ImagickPixel('white')); 
				$im->setColorSpace(imagick::COLORSPACE_RGB);
				$im->setImageFormat('jpeg');
				$im->resizeImage ($width, $height, Imagick::FILTER_GAUSSIAN, 1);
				$width = $im->getImageWidth();
				$im->writeimage(ABSPATH.'/wp-content/uploads/cache/'.$outfile);
			} else {
				$im = new imagick(ABSPATH.'/wp-content/uploads/cache/'.$outfile);
				$width = $im->getImageWidth();
			}
			
			return '<img src="'.get_site_url().'/wp-content/uploads/cache/'.$outfile.'" width="'.$width.'">';
		} else {
			return '<img src="'.$this->icon.'" width="48">';
		}
		
	}


}
?>
