<?php

class PostType {

	var $ID;
	var $details;
	var $meta = array();
	var $_images;
	var $_files;
	var $_thumb;

	function __construct($data) {
		if (is_object($data)) {
			$this->ID = $data->ID;
			$this->details = $data;
		} else {
			$this->ID = $data;
			$this->details = get_post($this->ID);
		}
	}

	function __toString() {
		return $this->details->post_title;
	}

	function __get($field) {
		switch ($field) {
			case 'date':
				return strtotime($this->details->post_date);
				
			case 'reference':
				return $this->details->post_name;

			case 'tags':
				$tags = wp_get_post_tags($this->ID);
				foreach ($tags as $index => $tag) {
					$tags[$index] = $tag->slug;
				}
				return $tags;

			case 'tagNames':
				$tags = wp_get_post_tags($this->ID);
				foreach ($tags as $index => $tag) {
					$tags[$index] = $tag->name;
				}
				return $tags;

			case 'thumb':
			case 'featured':
				$thumb = get_post_thumbnail_id($this->ID);
				if (!empty($thumb)) {
					$thumb = new Image($thumb);
				}
				return $thumb;

			case 'link':
				return get_permalink($this->ID);

			case 'images':
				if (empty($this->_images)) {
					$this->_images = $this->getImages();
				}
				return $this->_images;

			case 'files':
				if (empty($this->_files)) {
					$this->_files = $this->getFiles();
				}
				return $this->_files;

			case 'masthead':
				return $this->getMasthead();
				
			case 'content':
				return apply_filters('the_content',$this->post_content);

			case 'excerpt':
				$excerpt = strlen($this->post_except)? $this->post_except : wp_trim_words($this->post_content,50);
				return apply_filters('the_excerpt',$excerpt);
				
			default:
				if (is_object($this->details) && property_exists($this->details,$field)) {
					return $this->details->$field;
				} else {
					return $this->getField($field);
				}
		}

	}
	
	static function allposttypes() {
		global $allposttypes;
		if (empty($allposttypes)) {
			$allposttypes = get_post_types(array(
				'show_ui' => true,
			));
		}
		return $allposttypes;
	}
	
	static function getByUUID($uuid) {
		$query = new WP_Query(array(
			'post_type' => 'any',
			'meta_query' => array(
				array(
					'key' => 'uuid',
					'value' => $uuid,
					'compare' => '=',
				)
			)
		));
		$posts = $query->get_posts();
		if (!empty($posts)) {
			return new PostType($posts[0]);
		} else {
			return false;
		}
	}

	function getImages() {
		$images = array();
		
		$allimages = get_children(array(
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'post_parent' => $this->ID,
			'orderby' => 'menu_order',
			'order' => 'ASC',
		));

		$count = 0;
		foreach ($allimages as $image) {
			$images[$count] = new Image($image);
			$count++;
		}
		return $images;
	}
	
	function getFiles($MIMEType=NULL) {
		$files = array();
		if (isset($MIMEType)) {
			$MIMEType = 'post_mime_type='.$MIMEType.'&';
		}
		$allFiles = get_children($MIMEType.'post_type=attachment&orderby=menu_order&post_parent=' . $this->ID );
		foreach ($allFiles as $ID => $file) {
			$files[] = new File($ID,$file);
		}
		return $files;
	}	

	function getField($field,$default=NULL) {
		$value = get_field($field,$this->ID);
		if (empty($value)) {
			$value = $default;
		}
		return $value;

	}
	
	function json() {
		global $wpdb;
		
		// Return serialized version of this post
		$out = array();
		
		// Details
		$out['details'] = $this->details;
		if ($this->details->post_parent > 0) {
			$parent = new PostType($this->details->post_parent);
			$this->details->post_parent = $parent->uuid;
		}
		
		$out['featured'] = $this->featured;
		if ($out['featured']) {
			$out['featured'] = array($out['featured']->url('large'),$out['featured']->uuid);
		}
		
		// Meta
		$out['meta'] = get_post_meta($this->ID,'',true);
		foreach ($out['meta'] as $m => $val) {
			if (count($m) == 1) {
				$out['meta'][$m] = $val[0];
			}
		}
		$out['meta']['gulf_sharing_owner'] = home_url();
		
		// Fields
		$objects = get_field_objects($this->ID);
		$fields = get_fields($this->ID);
		$out['fields'] = $this->getFields($fields,$objects);
		
		// Attachments
		$attachments = get_posts( array(
			'post_type' => 'attachment',
			'posts_per_page' => -1,
			'post_parent' => $this->ID,
			'post_status' => 'inherit',
        ) );
		if (!empty($attachments)) {
			foreach ($attachments as $i => $attachment) {
				$post = new PostType($attachment);
				$mime = explode('/',$attachment->post_mime_type);
				if ($mime[0] == 'image') {
					$image = new Image($attachment);
					$attachments[$i]->guid = $image->url('large');
				}
				$attachments[$i]->uuid = $post->uuid;
			}
		}
		$out['attachments'] = $attachments;
		
		return $out;
		
	}
	
	function getFields($fields,$objects) {
		foreach ($fields as $field => $value) {
			$object = $objects[$field];
			switch ($object['type']) {
				case 'image':
					$value = (object) $value;
					$obj = new PostType($value->ID);
					$image = new Image($value->ID);
					$value = $obj->json();
					$value['details']->guid = $image->url('large');
					break;
				
				case 'file':
					$value = (object) $value;
					$obj = new PostType($value->ID);
					$value = $obj->json();
					break;
				
				case 'gallery':
					if (is_array($value) && count($value)) {
						foreach ($value as $i => $v) {
							$v = (object) $v;
							$obj = new PostType($v->ID);
							$value[$i] = $obj->json();
						}
					}
					break;
				
				case 'post_object':
				case 'page_link':
				case 'relationship':
					if (isset($value) && !is_array($value)) {
						$value = array($value);
					}
					if (is_array($value) && count($value)) {
						foreach ($value as $i => $v) {
							if (!is_object($v)) {
								$v = str_replace(home_url(),'',$v);
								$v = get_page_by_path($v,OBJECT,PostType::allposttypes());
							}
							$obj = new PostType($v->ID);
							if ($obj->gulf_sharing_share !== 'none') { // Make sure linked object is shareable
								$value[$i] = $obj->json();
							} else {
								unset($value[$i]);
							}
						}
					}
					break;
				
				case 'repeater':
					if (is_array($value) && count($value)) {
						$subobjects = array();
						foreach ($object['sub_fields'] as $subobject) {
							$subobjects[$subobject['name']] = $subobject;
						}
						
						foreach ($value as $i => $v) {
							$value[$i] = $this->getFields($v,$subobjects);
						}
					}
					break;
			}
		
			$fields[$field] = $value;
		

		}
		

		return $fields;
	}
	
	
	
	function processFields($fields,$objects=null,$fieldprefix='') {
		global $missinguuids;
		
		if (empty($objects)) {
			$objects = get_field_objects($this->ID);
		}
		
		foreach ($fields as $field => $value) {
			if (isset($objects[$field])) {
				$object = $objects[$field];
				switch ($object['type']) {
					case 'image':
						if (property_exists($value->meta,'uuid')) {
							$file = Image::getByUUID($value->meta->uuid);
							if (empty($file)) {
								$postid = gulf_create_image_id($value->details->guid,$value->meta->uuid,$this->ID);
							} else {
								$postid = $file->ID;
							}
							update_post_meta($this->ID,$fieldprefix.$field,$postid);
						}
						break;
						
					case 'file': 
						if (property_exists($value->meta,'uuid')) {
							$file = Document::getByUUID($value->meta->uuid);
							if (empty($file)) {
								$postid = gulf_create_image_id($value->details->guid,$value->meta->uuid,$this->ID);
							} else {
								$postid = $file->ID;
							}
							update_post_meta($this->ID,$fieldprefix.$field,$postid);
						}
						break;
						
					case 'gallery':
						if (is_array($value) && count($value)) {
							foreach ($value as $i => $v) {
//								$postid = gulf_create_image_id($v->details->guid,$value->meta->uuid,$this->ID);
//
//								$obj = new PostType($v->ID);
//								$value[$i] = $obj->json();
							}
						}						
						break;
						
					case 'post_object':
					case 'page_link':
					case 'relationship':
						if (is_array($value) && count($value)) {
							foreach ($value as $i => $v) {
								if (property_exists($v->meta,'uuid')) {
									$obj = PostType::getByUUID($v->meta->uuid);
									if (empty($obj)) {
										$missinguuids[] = $v->meta->uuid;
									} else {
										$metaname = $fieldprefix.$field;
										if ($object['multiple']) {
											$metaname .= '_'.$i;
										}
										update_post_meta($this->ID,$metaname,$obj->ID);
									}
								}
							}
						}
						break;
						
					case 'repeater':
						if (is_array($value) && count($value)) {
							$subobjects = array();
							foreach ($object['sub_fields'] as $subobject) {
								$subobjects[$subobject['name']] = $subobject;
							}
							
							foreach ($value as $i => $v) {
								$this->processFields($v,$subobjects,$field.'_'.$i.'_');
							}
							
						}						
						

						break;
				}

			}
		}

	}

}
?>
