<?php

// Timelines

register_post_type('timelineevent',
	array(
		'labels' => array(
			'name' => __('Timeline Events'),
			'singular_name' => __('Timeline Event'),
			'edit_item' => __('Edit Timeline Event'),
			'add_new_item' => __('Add a New Timeline Event'),
		),
		'public' => false,
		'show_ui' => true,
		'show_in_menu' => true,
		'exclude_from_search' => false,
		'menu_icon' => 'dashicons-calendar-alt',
		'show_in_rest' => true,
		'rewrite' => false,
	)
);


register_taxonomy('timeline',
	array(
		'timelineevent',
	),
	array(
		'labels' => array(
			'name' => __('Timelines'),
			'singular_name' => __('Timeline'),
		),
		'public' => true,
		'show_ui' => true,
		'show_in_menu' => true,
		'rewrite' => false,
	)
);


// Contacts
register_post_type('contact',
	array(
		'labels' => array(
			'name' => __('Contacts'),
			'singular_name' => __('Contact'),
			'edit_item' => __('Edit Contact'),
			'add_new_item' => __('Add a New Contact'),
		),
		'public' => false,
		'show_ui' => true,
		'show_in_menu' => true,
		'exclude_from_search' => false,
		'menu_icon' => 'dashicons-location',
		'show_in_rest' => true,
		'rewrite' => false,
	)
);


// Banners
register_post_type('banner',
	array(
		'labels' => array(
			'name' => __('Banners'),
			'singular_name' => __('Banner'),
			'edit_item' => __('Edit Banner'),
			'add_new_item' => __('Add a New Banner'),
		),
		'public' => false,
		'show_ui' => true,
		'show_in_menu' => true,
		'menu_icon' => 'dashicons-align-center',
		'show_in_rest' => true,
		'rewrite' => false,
	)
);


// Translations
register_post_type('translation',
	array(
		'labels' => array(
			'name' => __('Translations'),
			'singular_name' => __('Translation'),
			'edit_item' => __('Edit Translation'),
		),
		'public' => false,
		'show_ui' => true,
		'show_in_menu' => true,
		'capabilities' => array(
			'create_posts' => 'do_not_allow', 
		),
		'map_meta_cap' => true,
		'menu_icon' => 'dashicons-translation',
		'rewrite' => false,
	)
);


// Distributors
if (get_theme_mod('distributors')) {
	register_post_type('distributor',
		array(
			'labels' => array(
				'name' => __('Distributors'),
				'singular_name' => __('Distributor'),
				'edit_item' => __('Edit Distributor'),
			),
			'public' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'menu_icon' => 'dashicons-store',
			'has_archive' => 'distributors',
			'hierarchical' => true
		)
	);
	add_post_type_support('distributor','page-attributes');
}


// Products
if (get_theme_mod('products',true)) {
	register_post_type('gulfproduct',
		array(
			'labels' => array(
				'name' => __('Products'),
				'singular_name' => __('Product'),
				'edit_item' => __('Edit Product'),
			),
			'public' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'menu_icon' => 'dashicons-cart',
			'has_archive' => false,
			'supports' => array(
				'title',
				'editor',
				'excerpt',
				'thumbnail',
			),
			'hierarchical' => true,
			'rewrite' => array(
				'slug' => 'product',
			),
			'taxonomies' => array(
				'category',
			)
		)
	);
	
	register_taxonomy( 'gulf_product_category', array('gulfproduct'), 
		array(
			'labels' => array(
				'name' => __('Product Categories'),
				'singular_name' => __('Product Category'),
				'edit_item' => __('Edit Product Category'),
			),
			'public' => true,
			'publicly_queryable' => true,
			'hierarchical' => true,
			'show_in_quick_edit' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
//			'query_var' => 'product_category',
			'rewrite' => array(
				'slug' => 'product_category',
			),
		) 
	);
	
	add_action('restrict_manage_posts','restrict_listings_by_product_category');

}




function restrict_listings_by_product_category() {
	global $typenow;
	
	if ($typenow=='gulfproduct') {
		$taxonomy = 'gulf_product_category';
		$_taxonomy = get_taxonomy($taxonomy);
		$terms = get_terms($taxonomy);
		if(count($terms) > 0) {
			echo "<select name='$taxonomy' id='$taxonomy' class='postform'>";
			echo "<option value=''>Show All Product Categories</option>";
			foreach ($terms as $term) { 
				echo '<option value='. $term->slug, $_GET[$taxonomy] == $term->slug ? ' selected="selected"' : '','>' . $term->name .' (' . $term->count .')</option>'; 
			}
			echo "</select>";
		}

	}
}	
