<?php

// DISPLAY //
add_action('wp','gulf_products_show_empty_content');
function gulf_products_show_empty_content() {
	global $post;
	if (!empty($post) && $post->post_type == 'gulfproduct') {
		add_filter('gulf_hide_empty_content','__return_false');
	}
}

add_action('gulf_loop_after_article','gulf_products_show_tabs');
function gulf_products_show_tabs() {
	global $post;
	if (empty($post) || $post->post_type !== 'gulfproduct') {
		return;
	}
	

	$post = new PostType($post);
	$tabs = $post->getField('tabs');
	if (empty($tabs)) {
		return;
	}
	
	foreach ($tabs as $i => $tab) {
		$tabs[$i] = (object) $tab;
	}
	
	?>
	<div>
		<ul class="tabs" data-tabs id="product-tabs">
			<?php
			foreach ($tabs as $i => $tab) {
				$tabtext = $tab->tab_name? $tab->tab_name : $tab->title;
				?><li class="tabs-title <?php print $i==0? 'is-active' : '' ?>"><a href="#product-tabs-<?php print $i ?>"><?php print $tabtext ?></a></li><?php
			}
			?>
		</ul>
		<div class="tabs-content" data-tabs-content="product-tabs">
		<?php
		foreach ($tabs as $i => $tab) {
			?>
			<div id="product-tabs-<?php print $i ?>" class="tabs-panel <?php print $i==0? 'is-active' : '' ?>">
				<h3><?php print $tab->title ?></h3>
				<?php print $tab->content ?>
			</div>
			<?php
		}
		?>
		</div>
	</div>
	<?php
}



// ADMIN //
function gulf_products_add_meta_boxes() {
    $post_types = get_post_types();
    foreach( $post_types as $ptype ) {
        if ( $ptype == 'gulfproduct') {
            add_meta_box( 'gulf-products-selector', 'Attributes', 'gulf_products_meta_box', $ptype, 'side', 'core' );
        }
    }
}
add_action( 'add_meta_boxes', 'gulf_products_add_meta_boxes' );

function gulf_products_remove_meta_boxes() {
    $post_types = get_post_types();
    foreach( $post_types as $ptype ) {
        if ( $ptype == 'gulfproduct') {
            remove_meta_box( 'pageparentdiv', $ptype, 'normal' );
        }
    }
}
add_action( 'admin_menu' , 'gulf_products_remove_meta_boxes' );

function gulf_products_meta_box( $post ) {
    $post_meta = get_post_meta( $post->ID );
    $templates = wp_get_theme()->get_page_templates();
    $post_type_object = get_post_type_object($post->post_type);
    if ( $post_type_object->hierarchical ) {
        $dropdown_args = array(
            'post_type'        => 'page',
            'exclude_tree'     => $post->ID,
            'selected'         => $post->post_parent,
            'name'             => 'parent_id',
            'show_option_none' => __('(no parent)'),
            'sort_column'      => 'menu_order, post_title',
            'echo'             => 0,
        );

        $dropdown_args = apply_filters( 'page_attributes_dropdown_pages_args', $dropdown_args, $post );
        $pages = wp_dropdown_pages( $dropdown_args );

        if ( $pages ) { 
            echo "<p><strong>Parent</strong></p>";
            echo "<label class=\"screen-reader-text\" for=\"parent_id\">Parent</label>";
            echo $pages;
        }
    }

    // Template Selector
    echo "<p><strong>Template</strong></p>";
    echo "<select id=\"cpt-selector\" name=\"_wp_page_template\"><option value=\"default\">Default Template</option>";
    foreach ( $templates as $template_filename => $template_name ) {
		if ( isset($post_meta['_wp_page_template'][0]) && ($post_meta['_wp_page_template'][0] == $template_filename) ) {
			echo "<option value=\"$template_filename\" selected=\"selected\">$template_name</option>";
		} else {
			echo "<option value=\"$template_filename\">$template_name</option>";
		}
    }
    echo "</select>";

}

function save_gulf_products_template_meta_data( $post_id ) {

    if ( isset( $_REQUEST['_wp_page_template'] ) ) {
        update_post_meta( $post_id, '_wp_page_template', $_REQUEST['_wp_page_template'] );
    }
}
add_action( 'save_post' , 'save_gulf_products_template_meta_data' );

function custom_single_template($template) {
    global $post;

    $post_meta = ( $post ) ? get_post_meta( $post->ID ) : null;
    if ( isset($post_meta['_wp_page_template'][0]) && ( $post_meta['_wp_page_template'][0] != 'default' ) ) {
        $template = get_template_directory() . '/' . $post_meta['_wp_page_template'][0];
    }

    return $template;
}
//add_filter( 'single_template', 'custom_single_template' );
/** END Custom Post Type Template Selector **/#


// Add custom 404 filter to handle page parents
add_filter('request','gulf_products_query_override');
function gulf_products_query_override($queryvars) {
	if (array_key_exists('gulfproduct', $queryvars)) {
		$pathparts = explode('/',$queryvars['gulfproduct']);
		$queryvars['name'] = end($pathparts);
		unset($queryvars['page']);
		unset($queryvars['gulfproduct']);
	}
	return $queryvars;
}

//add_filter('template_redirect', 'gulf_products_404_override' );
function gulf_products_404_override() {
    global $wp_query;
	
	if ($wp_query->query_vars['post_type'] == 'gulfproduct') {
		status_header( 200 );
		$pathparts = explode('/',$wp_query->query_vars['gulfproduct']);
		$wp_query = new WP_Query(array(
			'post_type' => 'gulfproduct',
			'name' => end($pathparts),
		));
	}
}