<?php

/* ----------------------
			API
   ----------------------  */

// Defines functions for the theme api to collect shared content
add_action('wp_ajax_get_shared_content','gulf_get_shared_content');
add_action('wp_ajax_nopriv_get_shared_content','gulf_get_shared_content');
function gulf_get_shared_content() {
	global $wpdb;
	
	$type = getGet('type');
	$tax = getGet('tax');
	$menu = getGet('menu');
	if (empty($type) && empty($tax) && empty($menu)) {
		die('Content type missing');
	}

	if ($type) {
		$postquery = new WP_Query(array(
			'post_type' => $type,
			'post_status' => array('publish','trash'),
			'posts_per_page' => -1,
			'meta_query' => array(
				array(
					'key' => 'gulf_sharing_share',
					'value' => 'none',
					'compare' => '!=',
				)
			)
		));

		$out = array();
		foreach ($postquery->get_posts() as $post) {
			$post = new PostType($post);
			$json = $post->json();
			$out[] = $json;
		}
		
	} elseif ($tax) {
		$terms = get_terms(array(
			'taxonomy' => $tax,
		));
		
		$out = array();
		foreach ($terms as $term) {
			$term = new TermType($term);
			$json = $term->json();
			$out[] = $json;
		}
		
	} elseif ($menu) {
		$menuitems = wp_get_nav_menu_items($menu);
		$ids = array();
		foreach ($menuitems as $menuitem) {
			if ($menuitem->type == 'post_type') {
				$ids[] = $menuitem->ID;
				$ids[] = $menuitem->object_id;
				if ($menuitem->menu_item_parent > 0) {
					$ids[] = $menuitem->menu_item_parent;
				}
			}
		}
		$ids = $wpdb->get_col('SELECT post_id,meta_value FROM wp_postmeta WHERE post_id IN ('.implode(',',$ids).') AND meta_key="uuid"',0);
		$uuids = array_combine($ids, $wpdb->get_col('SELECT post_id,meta_value FROM wp_postmeta WHERE post_id IN ('.implode(',',$ids).') AND meta_key="uuid"',1));
		foreach ($menuitems as $i => $menuitem) {
			$menuitems[$i]->object_id = $uuids[$menuitems[$i]->object_id];
			if ($menuitems[$i]->menu_item_parent > 0) {
				$menuitems[$i]->menu_item_parent = $uuids[$menuitems[$i]->menu_item_parent];
			}
			$menuitems[$i]->menu = $menu;
			$menuitems[$i]->uuid = $uuids[$menuitem->ID];
		}
		
		$out = $menuitems;
	}
	
	$json = json_encode($out);
	$compress = getGet('compress',FALSE);
	if ($compress) {
		$json = gzcompress($json);
	}
	print $json;
	
	die();
}












// REST API - PROBABLY WON'T BE USED

// Add meta_query to post types
foreach ($sharedposttypes as $sharedposttype) {
	add_filter('rest_'.$sharedposttype.'_query', 'gulf_sharing_meta_query', 10, 2);
}
function gulf_sharing_meta_query($args, $request) {
	if (isset($request['filter']['meta_query'])) {
		$args['meta_query'] = $request['filter']['meta_query'];
	}
	return $args;
}

add_action( 'rest_api_init', 'gulf_sharing_register_extra_fields' );
function gulf_sharing_register_extra_fields() {
	global $sharedposttypes;
	register_rest_field( $sharedposttypes,
        'sharing',
        array(
            'get_callback'    => 'gulf_sharing_get_sharing',
            'update_callback' => null,
            'schema'          => null,
        )
    );	
	register_rest_field( $sharedposttypes,
        'uuids',
        array(
            'get_callback'    => 'gulf_sharing_get_uuids',
            'update_callback' => null,
            'schema'          => null,
        )
    );		
	register_rest_field( $sharedposttypes,
        'menu_order',
        array(
            'get_callback'    => 'gulf_sharing_get_menu_order',
            'update_callback' => null,
            'schema'          => null,
        )
    );		
	register_rest_field( $sharedposttypes,
        'custom_fields',
        array(
            'get_callback'    => 'gulf_sharing_get_custom_fields',
            'update_callback' => null,
            'schema'          => null,
        )
    );		
}
function gulf_sharing_get_sharing( $object, $field_name, $request ) {
    $share = get_post_meta( $object[ 'id' ], 'gulf_sharing_share', true );
    $priv = get_post_meta( $object[ 'id' ], 'gulf_sharing_privileges', true );
	return array('share'=>$share,'privileges'=>$priv,'owner'=>home_url());
}
function gulf_sharing_get_custom_fields( $object, $field_name, $request ) {
	$objects = get_field_objects($object['id']);
	$fields = get_fields($object['id']);
	$out = array();
	if (!empty($fields)) {
		foreach ($fields as $field => $value) {
			$out[$field] = array('value'=>$value,'id'=>$objects[$field]['key'],'type'=>$objects[$field]['type']);
			if ($objects[$field]['type'] == 'repeater') {
				$out[$field]['subfieldstypes'] = array();
				foreach ($objects[$field]['sub_fields'] as $subfield) {
					$out[$field]['subfieldstypes'][$subfield['name']] = $subfield['type'];
				}
			} elseif ($objects[$field]['type'] == 'relationship') {
				if (is_array($value)) {
					foreach ($value as $vi => $val) {
						if (is_a($val,'WP_Post')) {
							$value[$vi]->uuid = get_post_meta($val->ID,'uuid',true);
						}
					}
					$out[$field]['value'] = $value;
				}
			}
		}
	}
	return $out;
}
function gulf_sharing_get_uuids($object, $field_name, $request) {
    $uuid = get_post_meta( $object[ 'id' ], 'uuid', true );
	$parentid = wp_get_post_parent_id($object['id']);
	$parentuuid = $parentid > 0? get_post_meta( $parentid, 'uuid', true ) : '';
	return array('uuid'=>$uuid,'parent'=>$parentuuid);
}
function gulf_sharing_get_menu_order($object, $field_name, $request) {
	$post = get_post($object[ 'id' ]);
	return $post->menu_order;
}


//add_filter( 'rest_endpoints', 'gulf_rest_endpoints');
function gulf_rest_endpoints($endpoints ) {
	foreach ( $endpoints as $endpoint_key => $endpoint_value ) {
		if ( 0 !== strpos( $endpoint_key, '/wp/v2' ) ) {
			continue;
		}

		foreach ( $endpoint_value as $route_key => $route_value ) {
			if ( isset( $route_value['methods'] ) && 'GET' !== $route_value['methods'] ) {
				unset( $endpoints[ $endpoint_key ][ $route_key ] );
			}
		}
	}

	return $endpoints;
};

