<?php
add_action( 'widgets_init', function() {register_widget( "PageMenu_Widget" );} );

class PageMenu_Widget extends WP_Widget {

	public function __construct() {
		$widget_ops = array( 'description' => __( "Shows a menu for pages and children","gulfoil") );
		parent::__construct( 'page_menu', __('Page Menu',"gulfoil"), $widget_ops );
	}

	public function widget($args, $instance) {
		global $post;
		
		// Get menu
		$parent = ! empty( $instance['parent'] ) ? $instance['parent'] : false;

		/** This filter is documented in wp-includes/default-widgets.php */
		$instance['title'] = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		echo $args['before_widget'];

		if ( !empty($instance['title']) )
			echo $args['before_title'] . $instance['title'] . $args['after_title'];

		$options = array(
			'post_type' => 'page',
			'posts_per_page' => -1,
			'orderby' => 'menu_order',
			'order' => 'ASC',
		);
		if ($parent !== false) {
			$options['post_parent'] = $parent;
		}
		$pages = get_posts($options); 

		?>
<ul>
	<?php
	$parent = new PostType($parent);
	?>
	<li class="<?php print $post->ID==$parent->ID? 'active' : '' ?>"><a href="<?php print get_permalink($parent->ID) ?>"><?php print $parent->post_title ?></a></li>
	<ul>
	<?php
		foreach ($pages as $page) {
			?><li class="<?php print $post->ID==$page->ID? 'active' : '' ?>"><a href="<?php print get_permalink($page->ID) ?>"><?php print $page->post_title ?></a></li><?php
		}
		?>
	</ul>
</ul>
	<?php

		echo $args['after_widget'];
	}

	
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		if ( ! empty( $new_instance['title'] ) ) {
			$instance['title'] = strip_tags( stripslashes($new_instance['title']) );
		}
		if ( ! empty( $new_instance['parent'] ) ) {
			$instance['parent'] = (int) $new_instance['parent'];
		}
		return $instance;
	}

	public function form( $instance ) {
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$parent = isset( $instance['parent'] ) ? $instance['parent'] : '';

		// Get menus
		$pages = get_posts(array(
			'posts_per_page' => -1,
			'post_type' => 'page',
		));

		// If no menus exists, direct the user to go and create some.
		if ( !$pages ) {
			echo '<p>No pages have been created yet.</p>';
			return;
		}
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:') ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('parent'); ?>"><?php _e('Select top page:'); ?></label>
			<select id="<?php echo $this->get_field_id('parent'); ?>" name="<?php echo $this->get_field_name('parent'); ?>">
				<option value="0"><?php _e( '&mdash; Select &mdash;' ) ?></option>
		<?php
			foreach ( $pages as $page ) {
				echo '<option value="' . $page->ID . '"'
					. selected( $parent, $page->ID, false )
					. '>'. esc_html( $page->post_title ) . '</option>';
			}
		?>
			</select>
		</p>
		<?php
	}
}
